@@ -59,6 +59,11 @@ def cli(ctx: click.Context, config_path: str, local: bool) -> None:
     The parent group for the Fidesctl CLI.
     """
 
+    docs_link = "https://ethyca.github.io/fides/"
+    click.secho(
+        f"WARNING: 'Fidesctl' has been deprecated and replaced by a more robust 'Fides' tool, which includes existing 'fidesctl' functionality. Run `pip install ethyca-fides` to get the latest version of Fides and visit '{docs_link}' for up-to-date documentation.\n",
+        fg="red",
+    )
     ctx.ensure_object(dict)
     config = get_config(config_path)
 
