@@ -20,8 +20,8 @@ from fidesctl.cli.utils import (
     handle_okta_credentials_options,
     with_analytics,
 )
-from fidesctl.core import dataset as _dataset
-from fidesctl.core import system as _system
+from fidesctl.ctl.core import dataset as _dataset
+from fidesctl.ctl.core import system as _system
 
 
 @click.group(name="scan")
@@ -157,7 +157,7 @@ def scan_system_aws(
     Connect to an aws account and compares tracked resources to existing systems.
     Credentials can be supplied as options, a credentials reference to fidesctl
     config, or boto3 environment configuration.
-    Tracked resources: [Redshift, RDS]
+    Tracked resources: [Redshift, RDS, DynamoDb, S3]
 
     Outputs missing resources and has a non-zero exit if coverage is
     under the stated threshold.
